#line 1 "ad_loongarch_pipeline.cpp"
//
// Copyright (c) 2003, 2013, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2015, 2022, Loongson Technology. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/ad_loongarch.hpp"

//------------------Pipeline Methods-----------------------------------------
#ifndef PRODUCT
const char * Pipeline::stageName(uint s) {
  static const char * const _stage_names[] = {
    "undefined", "IF", "ID", "RD", "CA", "WB", "CM"
  };

  return (s <= 6 ? _stage_names[s] : "???");
}
#endif

uint Pipeline::functional_unit_latency(uint start, const Pipeline *pred) const {
  // See if the functional units overlap
  uint mask = resourcesUsedExclusively() & pred->resourcesUsedExclusively();
  if (mask == 0)
    return (start);

  for (uint i = 0; i < pred->resourceUseCount(); i++) {
    const Pipeline_Use_Element *predUse = pred->resourceUseElement(i);
    if (predUse->multiple())
      continue;

    for (uint j = 0; j < resourceUseCount(); j++) {
      const Pipeline_Use_Element *currUse = resourceUseElement(j);
      if (currUse->multiple())
        continue;

      if (predUse->used() & currUse->used()) {
        Pipeline_Use_Cycle_Mask x = predUse->mask();
        Pipeline_Use_Cycle_Mask y = currUse->mask();

        for ( y <<= start; x.overlaps(y); start++ )
          y <<= 1;
      }
    }
  }

  // There is the potential for overlap
  return (start);
}

// The following two routines assume that the root Pipeline_Use entity
// consists of exactly 1 element for each functional unit
// start is relative to the current cycle; used for latency-based info
uint Pipeline_Use::full_latency(uint delay, const Pipeline_Use &pred) const {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      uint min_delay = 8;
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        uint curr_delay = delay;
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= curr_delay; x.overlaps(y); curr_delay++ )
            y <<= 1;
        }
        if (min_delay > curr_delay)
          min_delay = curr_delay;
      }
      if (delay < min_delay)
      delay = min_delay;
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= delay; x.overlaps(y); delay++ )
            y <<= 1;
        }
      }
    }
  }

  return (delay);
}

void Pipeline_Use::add_usage(const Pipeline_Use &pred) {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        if ( !predUse->_mask.overlaps(currUse->_mask) ) {
          currUse->_used |= (1 << j);
          _resources_used |= (1 << j);
          currUse->_mask.Or(predUse->_mask);
          break;
        }
      }
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        currUse->_used |= (1 << j);
        _resources_used |= (1 << j);
        currUse->_mask.Or(predUse->_mask);
      }
    }
  }
}

uint Pipeline::operand_latency(uint opnd, const Pipeline *pred) const {
  int const default_latency = 1;

  assert(this, "NULL pipeline info");
  assert(pred, "NULL predecessor pipline info");

  if (pred->hasFixedLatency())
    return (pred->fixedLatency());

  // If this is not an operand, then assume a dependence with 0 latency
  if (opnd > _read_stage_count)
    return (0);

  uint writeStage = pred->_write_stage;
  uint readStage  = _read_stages[opnd-1];

  if (writeStage == stage_undefined || readStage == stage_undefined)
    return (default_latency);

  int delta = writeStage - readStage;
  if (delta < 0) delta = 0;

  return (delta);
}

Pipeline_Use_Cycle_Mask operator&(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask & in2._mask);
}

Pipeline_Use_Cycle_Mask operator|(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask | in2._mask);
}

static const Pipeline pipeline_class_Zero_Instructions(0, 0, true, 0, 0, false, false, false, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

static const Pipeline pipeline_class_Unknown_Instructions(0, 0, true, 0, 0, false, true, true, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

const Pipeline_Use_Element Pipeline_Use::elaborated_elements[10] = {
  Pipeline_Use_Element(0, 0, 0, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 1, 1, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 2, 2, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 3, 3, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 4, 4, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 5, 5, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 6, 6, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 7, 7, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 8, 8, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 9, 9, false, Pipeline_Use_Cycle_Mask(0))
};

const Pipeline_Use Pipeline_Use::elaborated_use(0, 0, 10, (Pipeline_Use_Element *)&elaborated_elements[0]);


// Pipeline Class "ialu_regI_regI"
static const enum machPipelineStages pipeline_reads_001[2] = {
  stage_RD,
  stage_RD 
};

static const enum machPipelineStages pipeline_res_stages_001[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_CA,        // DECODE
  stage_CA,        // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_001[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  1, // DECODE
  1, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_001[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x030, 4, 5, true,  Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_001(((uint)stage_WB)+1, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x3f, 0x0, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_mult"
static const enum machPipelineStages pipeline_res_stages_002[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_CA,        // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_002[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  1, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_002[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x020, 5, 5, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_002(((uint)stage_WB)+5, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x2f, 0x20, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "mulL_reg_reg"
static const Pipeline pipeline_class_003(((uint)stage_WB)+10, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x2f, 0x20, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "ialu_div"
static const Pipeline pipeline_class_004(((uint)stage_WB)+10, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x2f, 0x20, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "ialu_mod"
static const Pipeline pipeline_class_005(((uint)stage_WB)+10, 2, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x2f, 0x20, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "ialu_regL_regL"
static const Pipeline pipeline_class_006((uint)stage_WB, 2, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x3f, 0x0, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_regL_imm16"
static const enum machPipelineStages pipeline_reads_002[1] = {
  stage_RD 
};

static const Pipeline pipeline_class_007((uint)stage_WB, 1, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x3f, 0x0, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_loadL"
static const enum machPipelineStages pipeline_res_stages_003[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_RD,        // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_003[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  1, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_003[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x00000002)) 
};

static const Pipeline pipeline_class_008(((uint)stage_WB)+5, 1, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_storeL"
static const Pipeline pipeline_class_009((uint)stage_undefined, 2, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_regI_imm16"
static const Pipeline pipeline_class_010((uint)stage_WB, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x3f, 0x0, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_regI_mov"
static const Pipeline pipeline_class_011((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x3f, 0x0, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "empty"
static const enum machPipelineStages pipeline_res_stages_004[10] = {
  stage_undefined, // D1
  stage_undefined, // D2
  stage_undefined, // D3
  stage_undefined, // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_004[10] = {
  0, // D1
  0, // D2
  0, // D3
  0, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline pipeline_class_012((uint)stage_undefined, 0, false, 0, 0, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x0, 0x0, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_jump"
static const enum machPipelineStages pipeline_res_stages_005[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_RD         // FPU2
};

static const uint pipeline_res_cycles_005[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  1  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_005[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x200, 9, 9, false, Pipeline_Use_Cycle_Mask(0x00000002)) 
};

static const Pipeline pipeline_class_013((uint)stage_undefined, 0, false, 0, 0, false, true, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x20f, 0x200, 2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "pipe_alu_branch"
static const enum machPipelineStages pipeline_reads_003[3] = {
  stage_RD,
  stage_RD,
  stage_undefined 
};

static const Pipeline pipeline_class_014((uint)stage_undefined, 3, false, 0, 0, false, true, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x20f, 0x200, 2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "ialu_loadI"
static const Pipeline pipeline_class_015(((uint)stage_WB)+3, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_storeI"
static const Pipeline pipeline_class_016((uint)stage_undefined, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "fpu_regF_regF"
static const enum machPipelineStages pipeline_res_stages_006[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_CA,        // ALU2
  stage_CA,        // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_006[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  1, // ALU2
  1, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_006[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x0c0, 6, 7, true,  Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_017((uint)stage_WB, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0xcf, 0x0, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "fpu_div"
static const enum machPipelineStages pipeline_res_stages_007[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_CA,        // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_007[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  1, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_007[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x080, 7, 7, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_018((uint)stage_WB, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x8f, 0x80, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "fcvt_I2D"
static const enum machPipelineStages pipeline_res_stages_008[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_CA,        // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_008[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  1, // ALU2
  0, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_008[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x040, 6, 6, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_019((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x4f, 0x40, 2, (Pipeline_Use_Element *)&pipeline_res_mask_008[0]));

// Pipeline Class "fcvt_D2I"
static const Pipeline pipeline_class_020((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x4f, 0x40, 2, (Pipeline_Use_Element *)&pipeline_res_mask_008[0]));

// Pipeline Class "pipe_mfc1"
static const Pipeline pipeline_class_021((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "pipe_mtc1"
static const uint pipeline_res_cycles_009[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  5, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_009[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x0000003e)) 
};

static const Pipeline pipeline_class_022((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_009,
  Pipeline_Use(0x10f, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_009[0]));

// Pipeline Class "fpu_sqrt"
static const Pipeline pipeline_class_023((uint)stage_WB, 2, false, 0, 0, false, true, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x8f, 0x80, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "fpu_loadF"
static const Pipeline pipeline_class_024(((uint)stage_WB)+3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "fpu_storeF"
static const Pipeline pipeline_class_025((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "pipe_fpu_branch"
static const Pipeline pipeline_class_026((uint)stage_undefined, 3, false, 0, 0, false, true, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x20f, 0x200, 2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "fpu1_regF"
static const Pipeline pipeline_class_027((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0xcf, 0x0, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "long_memory_op"
static const Pipeline pipeline_class_028((uint)stage_undefined, 0, true, 30, 10, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x0, 0x0, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "simple_call"
static const enum machPipelineStages pipeline_res_stages_009[10] = {
  stage_undefined, // D1
  stage_undefined, // D2
  stage_undefined, // D3
  stage_undefined, // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_RD         // FPU2
};

static const uint pipeline_res_cycles_010[10] = {
  0, // D1
  0, // D2
  0, // D3
  0, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  1  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_010[1] = {
  Pipeline_Use_Element(0x200, 9, 9, false, Pipeline_Use_Cycle_Mask(0x00000002)) 
};

static const Pipeline pipeline_class_029((uint)stage_undefined, 0, true, 200, 10, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_009,
  (uint * const) pipeline_res_cycles_010,
  Pipeline_Use(0x200, 0x200, 1, (Pipeline_Use_Element *)&pipeline_res_mask_010[0]));

// Pipeline Class "call"
static const Pipeline pipeline_class_030((uint)stage_undefined, 0, true, 200, 10, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x0, 0x0, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_slow"
static const Pipeline pipeline_class_031((uint)stage_undefined, 0, true, 50, 20, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x0, 0x0, 0, (Pipeline_Use_Element *)NULL));

//------------------Inter-Instruction Latency--------------------------------
uint Node::latency(uint i) {
  uint j;
  // verify in legal range for inputs
  assert(i < len(), "index not in range");

  // verify input is not null
  Node *pred = in(i);
  if (!pred)
    return 0;

  if (pred->is_Proj())
    pred = pred->in(0);

  // if either node does not have pipeline info, use default
  const Pipeline *predpipe = pred->pipeline();
  assert(predpipe, "no predecessor pipeline info");

  if (predpipe->hasFixedLatency())
    return predpipe->fixedLatency();

  const Pipeline *currpipe = pipeline();
  assert(currpipe, "no pipeline info");

  if (!is_Mach())
    return 0;

  const MachNode *m = as_Mach();
  j = m->oper_input_base();
  if (i < j)
    return currpipe->functional_unit_latency(0, predpipe);

  // determine which operand this is in
  uint n = m->num_opnds();
  int delta = 0;

  uint k;
  for (k = 1; k < n; k++) {
    j += m->_opnds[k]->num_edges();
    if (i < j)
      break;
  }
  if (k < n)
    delta = currpipe->operand_latency(k,predpipe);

  return currpipe->functional_unit_latency(delta, predpipe);
}

// Descriptions for emitting different functional unit nops
void Bundle::initialize_nops(MachNode * nop_list[1]) {
  nop_list[0] = (MachNode *) new MachNopNode();
};

#ifndef PRODUCT
void Bundle::dump(outputStream *st) const {
  static const char * bundle_flags[] = {
    "",
    "use nop delay",
    "use unconditional delay",
    "use conditional delay",
    "used in conditional delay",
    "used in unconditional delay",
    "used in all conditional delays",
  };

  static const char *resource_names[10] = { "D1", "D2", "D3", "D4", "DECODE", "ALU1", "ALU2", "ALU", "FPU1", "FPU2" };

  bool needs_comma = false;

  if (_flags) {
    st->print("%s", bundle_flags[_flags]);
    needs_comma = true;
  };
  if (instr_count()) {
    st->print("%s%d instr%s", needs_comma ? ", " : "", instr_count(), instr_count() != 1 ? "s" : "");
    needs_comma = true;
  };
  uint r = resources_used();
  if (r) {
    st->print("%sresource%s:", needs_comma ? ", " : "", (r & (r-1)) != 0 ? "s" : "");
    for (uint i = 0; i < 10; i++)
      if ((r & (1 << i)) != 0)
        st->print(" %s", resource_names[i]);
    needs_comma = true;
  };
  st->print("\n");
}
#endif
const Pipeline *                              Node::pipeline_class() { return (&pipeline_class_Zero_Instructions); }
const Pipeline *                              Node::pipeline() const { return (&pipeline_class_Zero_Instructions); }

const Pipeline *                          MachNode::pipeline_class() { return (&pipeline_class_Unknown_Instructions); }
const Pipeline *                          MachNode::pipeline() const { return pipeline_class(); }



const Pipeline *                             loadINode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                             loadINode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                     loadI_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                     loadI_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                           loadI2BNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadI2BNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          loadI2UBNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                          loadI2UBNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                           loadI2SNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadI2SNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          loadI2USNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                          loadI2USNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                             loadLNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                             loadLNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                   loadL_unalignedNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                   loadL_unalignedNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                        storeL_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                        storeL_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *               storeL_reg_volatileNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *               storeL_reg_volatileNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *                     storeL_immL_0Node::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                     storeL_immL_0Node::pipeline() const { return (&pipeline_class_009); }

const Pipeline *            storeL_immL_0_volatileNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *            storeL_immL_0_volatileNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *                             loadNNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                             loadNNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                           loadN2PNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadN2PNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                             loadPNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                             loadPNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                         loadKlassNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadKlassNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        loadNKlassNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                        loadNKlassNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                      loadN2PKlassNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                      loadN2PKlassNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          loadConINode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                          loadConINode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                          loadConLNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                          loadConLNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                         loadRangeNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadRangeNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                            storePNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                            storePNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                   storeP_volatileNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                   storeP_volatileNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                  storeImmP_immP_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                  storeImmP_immP_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *         storeImmP_immP_0_volatileNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *         storeImmP_immP_0_volatileNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                            storeNNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                            storeNNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                   storeN_volatileNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                   storeN_volatileNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                          storeP2NNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                          storeP2NNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                 storeP2N_volatileNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                 storeP2N_volatileNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                       storeNKlassNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                       storeNKlassNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *              storeNKlass_volatileNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *              storeNKlass_volatileNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                     storeP2NKlassNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                     storeP2NKlassNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *            storeP2NKlass_volatileNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *            storeP2NKlass_volatileNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                  storeImmN_immN_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                  storeImmN_immN_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *         storeImmN_immN_0_volatileNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *         storeImmN_immN_0_volatileNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                     storeB_immB_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                     storeB_immB_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                            storeBNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                            storeBNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                             loadBNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                             loadBNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                     loadB_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                     loadB_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                            loadUBNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                            loadUBNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                    loadUB_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                    loadUB_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                             loadSNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                             loadSNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                           loadS2BNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadS2BNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                     loadS_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                     loadS_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                     storeI_immI_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                     storeI_immI_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *            storeI_immI_0_volatileNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *            storeI_immI_0_volatileNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                            storeINode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                            storeINode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                   storeI_volatileNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                   storeI_volatileNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                             loadFNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                             loadFNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                  loadConP_generalNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  loadConP_generalNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             loadConP_no_oop_cheapNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             loadConP_no_oop_cheapNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   loadConP_immP_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   loadConP_immP_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   loadConN_immN_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   loadConN_immN_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                          loadConNNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                          loadConNNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                     loadConNKlassNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                     loadConNKlassNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    TailCalljmpIndNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                    TailCalljmpIndNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                   CreateExceptionNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                   CreateExceptionNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                  RethrowExceptionNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                  RethrowExceptionNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                       jmpDir_longNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                       jmpDir_longNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                   jmpLoopEnd_longNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                   jmpLoopEnd_longNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *          jmpLoopEnd_reg_immI_longNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *          jmpLoopEnd_reg_immI_longNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                 jmpCon_flags_longNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                 jmpCon_flags_longNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                 branchConP_0_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                 branchConP_0_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *               branchConN2P_0_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *               branchConN2P_0_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *                   branchConP_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                   branchConP_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *             cmpN_null_branch_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *             cmpN_null_branch_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *              cmpN_reg_branch_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *              cmpN_reg_branch_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *          branchConIU_reg_reg_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *          branchConIU_reg_reg_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *          branchConIU_reg_imm_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *          branchConIU_reg_imm_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *           branchConI_reg_reg_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *           branchConI_reg_reg_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *           branchConI_reg_imm_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *           branchConI_reg_imm_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *         branchConL_regL_regL_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *         branchConL_regL_regL_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *        branchConUL_regL_regL_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *        branchConUL_regL_regL_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *         branchConL_regL_immL_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *         branchConL_regL_immL_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *        branchConUL_regL_immL_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *        branchConUL_regL_immL_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *           branchConF_reg_reg_longNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *           branchConF_reg_reg_longNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *           branchConD_reg_reg_longNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *           branchConD_reg_reg_longNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      jmpDir_shortNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                      jmpDir_shortNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                  jmpLoopEnd_shortNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                  jmpLoopEnd_shortNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *         jmpLoopEnd_reg_immI_shortNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *         jmpLoopEnd_reg_immI_shortNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                jmpCon_flags_shortNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                jmpCon_flags_shortNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                branchConP_0_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                branchConP_0_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *              branchConN2P_0_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *              branchConN2P_0_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *                  branchConP_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                  branchConP_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *            cmpN_null_branch_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *            cmpN_null_branch_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *             cmpN_reg_branch_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *             cmpN_reg_branch_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *         branchConIU_reg_reg_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *         branchConIU_reg_reg_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *         branchConIU_reg_imm_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *         branchConIU_reg_imm_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *          branchConI_reg_reg_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *          branchConI_reg_reg_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *          branchConI_reg_imm_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *          branchConI_reg_imm_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *        branchConL_regL_regL_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *        branchConL_regL_regL_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *       branchConUL_regL_regL_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *       branchConUL_regL_regL_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *        branchConL_regL_immL_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *        branchConL_regL_immL_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *       branchConUL_regL_immL_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *       branchConUL_regL_immL_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *          branchConF_reg_reg_shortNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *          branchConF_reg_reg_shortNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *          branchConD_reg_reg_shortNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *          branchConD_reg_reg_shortNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                 CallRuntimeDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                 CallRuntimeDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *        unnecessary_membar_acquireNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *        unnecessary_membar_acquireNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                    membar_acquireNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                    membar_acquireNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                        load_fenceNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        load_fenceNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               membar_acquire_lockNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               membar_acquire_lockNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *        unnecessary_membar_releaseNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *        unnecessary_membar_releaseNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    membar_releaseNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    membar_releaseNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       store_fenceNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       store_fenceNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               membar_release_lockNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               membar_release_lockNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *       unnecessary_membar_volatileNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *       unnecessary_membar_volatileNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   membar_volatileNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   membar_volatileNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                 membar_storestoreNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                 membar_storestoreNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               membar_storestore_0Node::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               membar_storestore_0Node::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                           castX2PNode::pipeline_class() { return (&pipeline_class_011); }
const Pipeline *                           castX2PNode::pipeline() const { return (&pipeline_class_011); }

const Pipeline *                           castP2XNode::pipeline_class() { return (&pipeline_class_011); }
const Pipeline *                           castP2XNode::pipeline() const { return (&pipeline_class_011); }

const Pipeline *                   MoveF2I_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   MoveF2I_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   MoveI2F_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   MoveI2F_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   MoveD2L_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   MoveD2L_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   MoveL2D_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   MoveL2D_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovI_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovI_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               cmovI_cmpI_reg_reg2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               cmovI_cmpI_reg_reg2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovI_cmpI_dst_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovI_cmpI_dst_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovI_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovI_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovI_cmpN_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovI_cmpN_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovP_cmpU_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovP_cmpU_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovP_cmpF_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovP_cmpF_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovP_cmpN_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovP_cmpN_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovN_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovN_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovP_cmpD_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovP_cmpD_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovN_cmpN_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovN_cmpN_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovI_cmpU_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovI_cmpU_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovI_cmpL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovI_cmpL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               cmovI_cmpUL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               cmovI_cmpUL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovP_cmpL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovP_cmpL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               cmovP_cmpUL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               cmovP_cmpUL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovI_cmpD_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovI_cmpD_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovP_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovP_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovP_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovP_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovL_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovL_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovN_cmpU_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovN_cmpU_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovN_cmpL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovN_cmpL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               cmovN_cmpUL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               cmovN_cmpUL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovN_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovN_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovL_cmpU_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovL_cmpU_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovL_cmpF_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovL_cmpF_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovL_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovL_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovL_cmpL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovL_cmpL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               cmovL_cmpUL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               cmovL_cmpUL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               cmovL_cmpL_reg_reg2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               cmovL_cmpL_reg_reg2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovL_cmpUL_reg_reg2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovL_cmpUL_reg_reg2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovL_cmpL_dst_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovL_cmpL_dst_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               cmovL_cmpUL_dst_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               cmovL_cmpUL_dst_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovL_cmpN_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovL_cmpN_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovL_cmpD_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovL_cmpD_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovD_cmpD_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovD_cmpD_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovF_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovF_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovD_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovD_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovD_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovD_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovI_cmpF_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovI_cmpF_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                cmovF_cmpF_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmovF_cmpF_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    cmpL3_reg_zeroNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    cmpL3_reg_zeroNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     cmpL3_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     cmpL3_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     cmpF3_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     cmpF3_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     cmpD3_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     cmpD3_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       clear_arrayNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       clear_arrayNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   clear_array_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   clear_array_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   string_compareLNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   string_compareLNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   string_compareUNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   string_compareUNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  string_compareLUNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  string_compareLUNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  string_compareULNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  string_compareULNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  string_indexofUUNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  string_indexofUUNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  string_indexofLLNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  string_indexofLLNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  string_indexofULNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  string_indexofULNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              string_indexof_conUUNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              string_indexof_conUUNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              string_indexof_conLLNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              string_indexof_conLLNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              string_indexof_conULNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              string_indexof_conULNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               string_indexof_charNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               string_indexof_charNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              stringL_indexof_charNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              stringL_indexof_charNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     has_negativesNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     has_negativesNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   string_compressNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   string_compressNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    string_inflateNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    string_inflateNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     string_equalsNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     string_equalsNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  encode_iso_arrayNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  encode_iso_arrayNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                encode_ascii_arrayNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                encode_ascii_arrayNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      addI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      addI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      addI_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      addI_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *        addI_salI_Reg_Reg_immI_1_4Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *        addI_salI_Reg_Reg_immI_1_4Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *      addI_salI_Reg_Reg_immI_1_4_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *      addI_salI_Reg_Reg_immI_1_4_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      addP_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      addP_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   addP_reg_reg_M8Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   addP_reg_reg_M8Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    addP_reg_imm12Node::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                    addP_reg_imm12Node::pipeline() const { return (&pipeline_class_010); }

const Pipeline *     addP_salL_Reg_RegI2L_immI_1_4Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *     addP_salL_Reg_RegI2L_immI_1_4Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      addL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      addL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      addL_Reg_immNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      addL_Reg_immNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                         absI_rRegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                         absI_rRegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                         absL_rRegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                         absL_rRegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      subI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      subI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *          subI_Reg_immI_M2047_2048Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *          subI_Reg_immI_M2047_2048Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                          negI_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                          negI_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                          negL_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                          negL_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *          subL_Reg_immL_M2047_2048Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *          subL_Reg_immL_M2047_2048Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      subL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      subL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      modI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      modI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      modL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      modL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      mulI_Reg_RegNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                      mulI_Reg_RegNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                      divI_Reg_RegNode::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                      divI_Reg_RegNode::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                      divF_Reg_RegNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      divF_Reg_RegNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      divD_Reg_RegNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      divD_Reg_RegNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      mulL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      mulL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    mulHiL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    mulHiL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      divL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      divL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      addF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                      addF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                      subF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                      subF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                      addD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                      addD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                      subD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                      subD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                          negF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                          negF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                          negD_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                          negD_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                      mulF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                      mulF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                      mulD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                      mulD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                          absF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                          absF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                          absD_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                          absD_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                         sqrtD_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                         sqrtD_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                         sqrtF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                         sqrtF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                     maddF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                     maddF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                     maddD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                     maddD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                     msubF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                     msubF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                     msubD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                     msubD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    mnaddF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    mnaddF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                  mnaddF_reg_reg_0Node::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                  mnaddF_reg_reg_0Node::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    mnaddD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    mnaddD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                  mnaddD_reg_reg_0Node::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                  mnaddD_reg_reg_0Node::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    mnsubF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    mnsubF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                  mnsubF_reg_reg_0Node::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                  mnsubF_reg_reg_0Node::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    mnsubD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    mnsubD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                  mnsubD_reg_reg_0Node::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                  mnsubD_reg_reg_0Node::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                     copySignF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                     copySignF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                     copySignD_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                     copySignD_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *               andI_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               andI_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *         andI_Reg_immI_nonneg_maskNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *         andI_Reg_immI_nonneg_maskNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *         andL_Reg_immL_nonneg_maskNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *         andL_Reg_immL_nonneg_maskNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               xorI_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               xorI_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  xorI_Reg_immI_M1Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  xorI_Reg_immI_M1Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               xorL_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               xorL_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                     lbu_and_lmaskNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                     lbu_and_lmaskNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                   lbu_and_lmask_0Node::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                   lbu_and_lmask_0Node::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                     lbu_and_rmaskNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                     lbu_and_rmaskNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                      andI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      andI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    andnI_Reg_nRegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    andnI_Reg_nRegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  andnI_Reg_nReg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  andnI_Reg_nReg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                     ornI_Reg_nRegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                     ornI_Reg_nRegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   ornI_Reg_nReg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   ornI_Reg_nReg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    andnI_nReg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    andnI_nReg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  andnI_nReg_Reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  andnI_nReg_Reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                     ornI_nReg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                     ornI_nReg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   ornI_nReg_Reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   ornI_nReg_Reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      andL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      andL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *               andL_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               andL_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             andL2I_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             andL2I_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  andL_Reg_immL_M8Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  andL_Reg_immL_M8Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  andL_Reg_immL_M5Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  andL_Reg_immL_M5Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  andL_Reg_immL_M7Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  andL_Reg_immL_M7Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  andL_Reg_immL_M4Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  andL_Reg_immL_M4Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                andL_Reg_immL_M121Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                andL_Reg_immL_M121Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                       orL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                       orL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    orL_Reg_P2XRegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    orL_Reg_P2XRegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                  orL_Reg_P2XReg_0Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                  orL_Reg_P2XReg_0Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      xorL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      xorL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      salI_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      salI_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           salI_Reg_imm_and_M65536Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           salI_Reg_imm_and_M65536Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                         land7_2_sNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                         land7_2_sNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                               i2sNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                               i2sNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                               i2bNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                               i2bNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   salI_RegL2I_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   salI_RegL2I_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      salI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      salI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      salL_Reg_immNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      salL_Reg_immNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      salL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      salL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      sarL_Reg_immNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      sarL_Reg_immNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *             sarL2I_Reg_immI_32_63Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *             sarL2I_Reg_immI_32_63Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      sarL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      sarL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      slrL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      slrL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                slrL_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                slrL_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *    slrL_Reg_immI_0_31_and_max_intNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *    slrL_Reg_immI_0_31_and_max_intNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *             slrL_P2XReg_immI_0_31Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *             slrL_P2XReg_immI_0_31Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *               slrL_Reg_immI_32_63Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *               slrL_Reg_immI_32_63Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *             slrL_Reg_immI_convL2INode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *             slrL_Reg_immI_convL2INode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *            slrL_P2XReg_immI_32_63Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *            slrL_P2XReg_immI_32_63Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      xorI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      xorI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                       orI_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                       orI_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                       orI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                       orI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              rotI_shr_logical_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              rotI_shr_logical_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            rotI_shr_logical_Reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            rotI_shr_logical_Reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   orI_Reg_castP2XNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   orI_Reg_castP2XNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 orI_Reg_castP2X_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 orI_Reg_castP2X_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               shr_logical_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               shr_logical_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *   shr_logical_Reg_imm_nonneg_maskNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *   shr_logical_Reg_imm_nonneg_maskNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                rolI_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                rolI_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              rolI_Reg_immI_0_31_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              rolI_Reg_immI_0_31_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                rolL_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                rolL_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              rolL_Reg_immI_0_31_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              rolL_Reg_immI_0_31_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               rolL_Reg_immI_32_63Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               rolL_Reg_immI_32_63Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             rolL_Reg_immI_32_63_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             rolL_Reg_immI_32_63_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                rorI_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                rorI_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              rorI_Reg_immI_0_31_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              rorI_Reg_immI_0_31_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                rorL_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                rorL_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              rorL_Reg_immI_0_31_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              rorL_Reg_immI_0_31_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               rorL_Reg_immI_32_63Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               rorL_Reg_immI_32_63Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             rorL_Reg_immI_32_63_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             rorL_Reg_immI_32_63_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                          rolI_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                          rolI_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                          rolL_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                          rolL_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                          rorI_immNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                          rorI_immNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *                          rorI_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                          rorI_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                          rorL_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                          rorL_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                          rorL_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                          rorL_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *               shr_logical_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               shr_logical_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 shr_arith_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 shr_arith_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 shr_arith_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 shr_arith_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                           convI2BNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                           convI2BNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                       convI2L_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                       convI2L_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                       convL2I_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                       convL2I_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                       convL2D_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       convL2D_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   convD2I_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   convD2I_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   convD2L_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   convD2L_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   convF2I_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   convF2I_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   convF2L_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   convF2L_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       convL2F_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       convL2F_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       convI2F_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                       convI2F_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                            roundDNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            roundDNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  cmpLTMask_immI_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  cmpLTMask_immI_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cmpLTMaskNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cmpLTMaskNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           convP2BNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                           convP2BNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                   convI2D_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                   convI2D_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                   convF2D_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                   convF2D_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                   convD2F_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                   convD2F_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                     encodeHeapOopNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                     encodeHeapOopNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *            encodeHeapOop_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *            encodeHeapOop_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                     decodeHeapOopNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                     decodeHeapOopNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *            decodeHeapOop_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *            decodeHeapOop_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *              encodeKlass_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *              encodeKlass_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *              decodeKlass_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *              decodeKlass_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                          tlsLoadPNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                          tlsLoadPNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                       checkCastPPNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                       checkCastPPNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                            castPPNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                            castPPNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                            castIINode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                            castIINode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                            castLLNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                            castLLNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                            castFFNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                            castFFNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                            castDDNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                            castDDNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                           castVVXNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                           castVVXNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                           castVVYNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                           castVVYNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                               RetNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                               RetNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                        tailjmpIndNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                        tailjmpIndNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              CallStaticJavaDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              CallStaticJavaDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *             CallDynamicJavaDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *             CallDynamicJavaDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                CallLeafNoFPDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                CallLeafNoFPDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     prefetchAllocNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     prefetchAllocNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    CallLeafDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    CallLeafDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            loadUSNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                            loadUSNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                    loadUS_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                    loadUS_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                            storeCNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                            storeCNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          storeC_0Node::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                          storeC_0Node::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                   loadConF_immF_0Node::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                   loadConF_immF_0Node::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                          loadConFNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                          loadConFNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                   loadConD_immD_0Node::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                   loadConD_immD_0Node::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                          loadConDNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                          loadConDNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                        storeF_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        storeF_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                     storeF_immF_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                     storeF_immF_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                             loadDNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                             loadDNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                   loadD_unalignedNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                   loadD_unalignedNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        storeD_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        storeD_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                     storeD_immD_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                     storeD_immD_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                           loadSSINode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadSSINode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          storeSSINode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                          storeSSINode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                           loadSSLNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadSSLNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          storeSSLNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                          storeSSLNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                           loadSSPNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadSSPNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          storeSSPNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                          storeSSPNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                           loadSSFNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadSSFNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          storeSSFNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                          storeSSFNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                           loadSSDNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadSSDNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          storeSSDNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                          storeSSDNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                       cmpFastLockNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       cmpFastLockNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     cmpFastUnlockNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     cmpFastUnlockNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        storeImmCMNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                        storeImmCMNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                ShouldNotReachHereNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                ShouldNotReachHereNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                      leaP12NarrowNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                      leaP12NarrowNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *                      leaPIdxScaleNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                      leaPIdxScaleNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *               partialSubtypeCheckNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               partialSubtypeCheckNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                 storePConditionalNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                 storePConditionalNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                 storeIConditionalNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                 storeIConditionalNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                 storeLConditionalNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                 storeLConditionalNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                       loadPLockedNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                       loadPLockedNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                   compareAndSwapINode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                   compareAndSwapINode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                   compareAndSwapLNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                   compareAndSwapLNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                   compareAndSwapPNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                   compareAndSwapPNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                   compareAndSwapNNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                   compareAndSwapNNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                      get_and_setINode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      get_and_setINode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      get_and_setLNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      get_and_setLNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      get_and_setNNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      get_and_setNNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      get_and_setPNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      get_and_setPNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      get_and_addLNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      get_and_addLNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               get_and_addL_no_resNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               get_and_addL_no_resNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      get_and_addINode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      get_and_addINode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               get_and_addI_no_resNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               get_and_addI_no_resNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               compareAndExchangeINode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               compareAndExchangeINode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               compareAndExchangeLNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               compareAndExchangeLNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               compareAndExchangePNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               compareAndExchangePNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               compareAndExchangeNNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               compareAndExchangeNNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               weakCompareAndSwapINode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               weakCompareAndSwapINode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               weakCompareAndSwapLNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               weakCompareAndSwapLNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               weakCompareAndSwapPNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               weakCompareAndSwapPNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *           weakCompareAndSwapP_acqNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *           weakCompareAndSwapP_acqNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               weakCompareAndSwapNNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               weakCompareAndSwapNNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      minI_Reg_RegNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      minI_Reg_RegNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      maxI_Reg_RegNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      maxI_Reg_RegNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     maxI_Reg_zeroNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     maxI_Reg_zeroNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                zerox_long_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                zerox_long_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                       combine_i2lNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                       combine_i2lNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                     combine_i2l_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                     combine_i2l_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               convI2L_reg_reg_zexNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               convI2L_reg_reg_zexNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             convL2I2L_reg_reg_zexNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             convL2I2L_reg_reg_zexNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    loadUI2L_rmaskNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                    loadUI2L_rmaskNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                    loadUI2L_lmaskNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                    loadUI2L_lmaskNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                  loadUI2L_lmask_0Node::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                  loadUI2L_lmask_0Node::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                safePoint_poll_tlsNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                safePoint_poll_tlsNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                    roundFloat_nopNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                    roundFloat_nopNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                   roundDouble_nopNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                   roundDouble_nopNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                 bytes_reverse_intNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 bytes_reverse_intNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                bytes_reverse_longNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                bytes_reverse_longNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *      bytes_reverse_unsigned_shortNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *      bytes_reverse_unsigned_shortNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               bytes_reverse_shortNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               bytes_reverse_shortNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                countLeadingZerosINode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                countLeadingZerosINode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                countLeadingZerosLNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                countLeadingZerosLNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *               countTrailingZerosINode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *               countTrailingZerosINode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *               countTrailingZerosLNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *               countTrailingZerosLNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                         popCountINode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         popCountINode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     popCountI_memNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     popCountI_memNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         popCountLNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         popCountLNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     popCountL_memNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     popCountL_memNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           loadV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           loadV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           loadV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           loadV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          storeV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          storeV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          storeV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          storeV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           repl16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           repl16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       repl16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       repl16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            repl8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            repl8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        repl8S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        repl8S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            repl4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            repl4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        repl4I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        repl4I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            repl2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            repl2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        repl2L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        repl2L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            repl4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            repl4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            repl2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            repl2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           repl32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           repl32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       repl32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       repl32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           repl16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           repl16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       repl16S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       repl16S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            repl8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            repl8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        repl8I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        repl8I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            repl4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            repl4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        repl4L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        repl4L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            repl8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            repl8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            repl4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            repl4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            add16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            add16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        add16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        add16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      add16B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      add16B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             add8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             add8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         add8S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         add8S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       add8S_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       add8S_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             add4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             add4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         add4I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         add4I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       add4I_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       add4I_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             add2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             add2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         add2L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         add2L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       add2L_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       add2L_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             add4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             add4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             add2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             add2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            add32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            add32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        add32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        add32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      add32B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      add32B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            add16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            add16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        add16S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        add16S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      add16S_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      add16S_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             add8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             add8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         add8I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         add8I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       add8I_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       add8I_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             add4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             add4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         add4L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         add4L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       add4L_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       add4L_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             add8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             add8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             add4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             add4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sub16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sub16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        sub16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        sub16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sub8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sub8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sub8S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sub8S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sub4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sub4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sub4I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sub4I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sub2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sub2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sub2L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sub2L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sub4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sub4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sub2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sub2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sub32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sub32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        sub32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        sub32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sub16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sub16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        sub16S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        sub16S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sub8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sub8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sub8I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sub8I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sub4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sub4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sub4L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sub4L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sub8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sub8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sub4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sub4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            mul16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            mul16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             mul8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             mul8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             mul4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             mul4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             mul2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             mul2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             mul4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             mul4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             mul2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             mul2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            mul32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            mul32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            mul16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            mul16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             mul8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             mul8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             mul4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             mul4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             mul8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             mul8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             mul4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             mul4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             div4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             div4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             div2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             div2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             div8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             div8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             div4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             div4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            abs16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            abs16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             abs8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             abs8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             abs4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             abs4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             abs2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             abs2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             abs4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             abs4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             abs2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             abs2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            abs32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            abs32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            abs16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            abs16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             abs8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             abs8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             abs4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             abs4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             abs8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             abs8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             abs4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             abs4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            absd4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            absd4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            absd2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            absd2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            absd8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            absd8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            absd4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            absd4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            max16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            max16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             max8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             max8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             max4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             max4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             max2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             max2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             max4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             max4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             max2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             max2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            max32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            max32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            max16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            max16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             max8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             max8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             max4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             max4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             max8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             max8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             max4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             max4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            min16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            min16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             min8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             min8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             min4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             min4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             min2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             min2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             min4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             min4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             min2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             min2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            min32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            min32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            min16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            min16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             min8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             min8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             min4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             min4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             min8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             min8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             min4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             min4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             neg4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             neg4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             neg4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             neg4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             neg2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             neg2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             neg8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             neg8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             neg8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             neg8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             neg4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             neg4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sqrt4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sqrt4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sqrt2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sqrt2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sqrt8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sqrt8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sqrt4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sqrt4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           madd16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           madd16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         madd16B_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         madd16B_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            madd8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            madd8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          madd8S_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          madd8S_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            madd4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            madd4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          madd4I_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          madd4I_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            madd2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            madd2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          madd2L_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          madd2L_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            madd4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            madd4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            madd2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            madd2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           madd32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           madd32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         madd32B_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         madd32B_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           madd16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           madd16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         madd16S_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         madd16S_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            madd8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            madd8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          madd8I_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          madd8I_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            madd4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            madd4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          madd4L_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          madd4L_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            madd8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            madd8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            madd4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            madd4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           msub16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           msub16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            msub8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            msub8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            msub4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            msub4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            msub2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            msub2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            msub4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            msub4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            msub2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            msub2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           msub32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           msub32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           msub16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           msub16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            msub8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            msub8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            msub4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            msub4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            msub8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            msub8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            msub4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            msub4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           nmadd4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           nmadd4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         nmadd4F_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         nmadd4F_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           nmadd2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           nmadd2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         nmadd2D_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         nmadd2D_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           nmadd8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           nmadd8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         nmadd8F_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         nmadd8F_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           nmadd4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           nmadd4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         nmadd4D_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         nmadd4D_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           nmsub4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           nmsub4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         nmsub4F_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         nmsub4F_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           nmsub2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           nmsub2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         nmsub2D_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         nmsub2D_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           nmsub8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           nmsub8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         nmsub8F_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         nmsub8F_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           nmsub4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           nmsub4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         nmsub4D_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         nmsub4D_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      muladd8Sto4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      muladd8Sto4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     muladd16Sto8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     muladd16Sto8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         shiftcntXNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         shiftcntXNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       shiftcntX_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       shiftcntX_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         shiftcntYNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         shiftcntYNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       shiftcntY_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       shiftcntY_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sll16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sll16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        sll16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        sll16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sll8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sll8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sll8S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sll8S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sll4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sll4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sll4I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sll4I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sll2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sll2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sll2L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sll2L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sll32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sll32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        sll32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        sll32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sll16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sll16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        sll16S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        sll16S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sll8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sll8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sll8I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sll8I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sll4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sll4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sll4L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sll4L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            srl16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            srl16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        srl16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        srl16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             srl8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             srl8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         srl8S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         srl8S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             srl4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             srl4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         srl4I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         srl4I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             srl2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             srl2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         srl2L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         srl2L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            srl32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            srl32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        srl32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        srl32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            srl16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            srl16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        srl16S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        srl16S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             srl8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             srl8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         srl8I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         srl8I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             srl4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             srl4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         srl4L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         srl4L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sra16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sra16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        sra16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        sra16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sra8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sra8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sra8S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sra8S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sra4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sra4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sra4I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sra4I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sra2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sra2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sra2L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sra2L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sra32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sra32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        sra32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        sra32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            sra16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            sra16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        sra16S_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        sra16S_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sra8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sra8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sra8I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sra8I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             sra4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             sra4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         sra4L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         sra4L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            rotr4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            rotr4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        rotr4I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        rotr4I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            rotr2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            rotr2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        rotr2L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        rotr2L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            rotr8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            rotr8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        rotr8I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        rotr8I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            rotr4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            rotr4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        rotr4L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        rotr4L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            rotl4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            rotl4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        rotl4I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        rotl4I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            rotl2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            rotl2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        rotl2L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        rotl2L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            rotl8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            rotl8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        rotl8I_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        rotl8I_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            rotl4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            rotl4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        rotl4L_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        rotl4L_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            andV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            andV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        and16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        and16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      and16B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      and16B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            andV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            andV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        and32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        and32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      and32B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      and32B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             orV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             orV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         or16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         or16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       or16B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       or16B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                             orV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                             orV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         or32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         or32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       or32B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       or32B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            xorV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            xorV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        xor16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        xor16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      xor16B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      xor16B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            xorV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            xorV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        xor32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        xor32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      xor32B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      xor32B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            norV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            norV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV16_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV16_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV16_1Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV16_1Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV16_2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV16_2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV16_3Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV16_3Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV16_4Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV16_4Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        nor16B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        nor16B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      nor16B_imm_1Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      nor16B_imm_1Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      nor16B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      nor16B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      nor16B_imm_2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      nor16B_imm_2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            norV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            norV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV32_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV32_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV32_1Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV32_1Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV32_2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV32_2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV32_3Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV32_3Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          norV32_4Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          norV32_4Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        nor32B_immNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        nor32B_immNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      nor32B_imm_1Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      nor32B_imm_1Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      nor32B_imm_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      nor32B_imm_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      nor32B_imm_2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      nor32B_imm_2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           andnV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           andnV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_1Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_1Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_3Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_3Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_5Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_5Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_4Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_4Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_6Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_6Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_7Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_7Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_9Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_9Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV16_8Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV16_8Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        andnV16_10Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        andnV16_10Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           andnV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           andnV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_1Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_1Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_3Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_3Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_5Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_5Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_4Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_4Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_6Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_6Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_7Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_7Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_9Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_9Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         andnV32_8Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         andnV32_8Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        andnV32_10Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        andnV32_10Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            ornV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            ornV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_1Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_1Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_3Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_3Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_5Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_5Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_4Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_4Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_6Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_6Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_7Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_7Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_9Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_9Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV16_8Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV16_8Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         ornV16_10Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         ornV16_10Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            ornV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            ornV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_1Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_1Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_2Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_2Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_3Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_3Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_5Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_5Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_4Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_4Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_6Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_6Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_7Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_7Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_9Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_9Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          ornV32_8Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          ornV32_8Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         ornV32_10Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         ornV32_10Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_add16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_add16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_add8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_add8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_add4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_add4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_add2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_add2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_add4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_add4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_add2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_add2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_add32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_add32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_add16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_add16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_add8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_add8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_add4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_add4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_add8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_add8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_add4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_add4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_mul16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_mul16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_mul8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_mul8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_mul4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_mul4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_mul2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_mul2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_mul4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_mul4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_mul2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_mul2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_mul32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_mul32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_mul16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_mul16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_mul8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_mul8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_mul4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_mul4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_mul8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_mul8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_mul4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_mul4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_max16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_max16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_max8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_max8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_max4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_max4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_max2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_max2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_max32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_max32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_max16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_max16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_max8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_max8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_max4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_max4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_min16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_min16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_min8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_min8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_min4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_min4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_min2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_min2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_min32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_min32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_min16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_min16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_min8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_min8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_min4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_min4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_and16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_and16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_and8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_and8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_and4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_and4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_and2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_and2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_and32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_and32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_and16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_and16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_and8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_and8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_and4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_and4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_or16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_or16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       reduce_or8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       reduce_or8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       reduce_or4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       reduce_or4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       reduce_or2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       reduce_or2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_or32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_or32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_or16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_or16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       reduce_or8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       reduce_or8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       reduce_or4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       reduce_or4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_xor16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_xor16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_xor8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_xor8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_xor4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_xor4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_xor2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_xor2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_xor32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_xor32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     reduce_xor16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     reduce_xor16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_xor8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_xor8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reduce_xor4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      reduce_xor4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           round2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           round2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                           round4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                           round4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       cvt16Bto16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       cvt16Bto16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       cvt16Sto16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       cvt16Sto16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt8Sto8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt8Sto8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt8Sto8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt8Sto8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt8Ito8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt8Ito8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Ito4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Ito4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Ito4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Ito4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt8Ito8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt8Ito8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Ito4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Ito4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Lto4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Lto4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Lto4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Lto4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt2Lto2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt2Lto2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Lto4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Lto4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt8Fto8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt8Fto8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Fto4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Fto4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt8Fto8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt8Fto8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Fto4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Fto4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Fto4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Fto4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Dto4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Dto4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Dto4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Dto4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt2Dto2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt2Dto2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         cvt4Dto4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         cvt4Dto4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      reinterpretXNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                      reinterpretXNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                      reinterpretYNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                      reinterpretYNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                    reinterpretX2YNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    reinterpretX2YNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    reinterpretY2XNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    reinterpretY2XNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         insert16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         insert16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          insert8SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          insert8SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          insert4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          insert4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          insert2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          insert2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          insert4FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          insert4FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          insert2DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          insert2DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         insert32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         insert32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         insert16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                         insert16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          insert8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          insert8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          insert4LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          insert4LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          insert8FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          insert8FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          insert4DNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          insert4DNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          blendV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          blendV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          blendV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          blendV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       loadmask16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       loadmask16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       loadmask32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       loadmask32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       loadmask16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       loadmask16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      storemask16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      storemask16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      storemask32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      storemask32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      storemask16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      storemask16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                anytrue_in_maskV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                anytrue_in_maskV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                alltrue_in_maskV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                alltrue_in_maskV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                anytrue_in_maskV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                anytrue_in_maskV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                alltrue_in_maskV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                alltrue_in_maskV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            cmpV16Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            cmpV16Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            cmpV32Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            cmpV32Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        loadcon16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        loadcon16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        loadcon32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        loadcon32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    loadShuffle16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    loadShuffle16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    loadShuffle32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    loadShuffle32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    loadShuffle16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    loadShuffle16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      rearrange16BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      rearrange16BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      rearrange32BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      rearrange32BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      rearrange16SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      rearrange16SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        popcount4INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        popcount4INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        popcount8INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        popcount8INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *        compareAndSwapP_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *        compareAndSwapP_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *        compareAndSwapN_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *        compareAndSwapN_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *     compareAndSwapPAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *     compareAndSwapPAcq_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *     compareAndSwapNAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *     compareAndSwapNAcq_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *    compareAndExchangeN_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *    compareAndExchangeN_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *    compareAndExchangeP_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *    compareAndExchangeP_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline * compareAndExchangeNAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline * compareAndExchangeNAcq_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline * compareAndExchangePAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline * compareAndExchangePAcq_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *    weakCompareAndSwapN_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *    weakCompareAndSwapN_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *    weakCompareAndSwapP_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *    weakCompareAndSwapP_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline * weakCompareAndSwapNAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline * weakCompareAndSwapNAcq_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline * weakCompareAndSwapPAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline * weakCompareAndSwapPAcq_shenandoahNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                            zLoadPNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                            zLoadPNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  zCompareAndSwapPNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  zCompareAndSwapPNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              zCompareAndSwapP_acqNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              zCompareAndSwapP_acqNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              zCompareAndSwapPWeakNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              zCompareAndSwapPWeakNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *          zCompareAndSwapPWeak_acqNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *          zCompareAndSwapPWeak_acqNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              zCompareAndExchangePNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              zCompareAndExchangePNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *          zCompareAndExchangeP_acqNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *          zCompareAndExchangeP_acqNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       zGetAndSetPNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       zGetAndSetPNode::pipeline() const { return (&pipeline_class_031); }
// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DLOONGARCH64=1
#ifndef LOONGARCH64
#  error "LOONGARCH64 must be defined"
#endif // LOONGARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
